%define uname   UHD
%define major   003
%define libname %mklibname %{name} %{major}
%define devname %mklibname -d %{name}

Name:           uhd
Summary:        Universal Hardware Driver for Ettus Research products
Version:        3.10.1.1
Release:        %mkrel 1
Group:          Communications/Radio
License:        GPLv3+
URL:            http://code.ettus.com/redmine/ettus/projects/uhd/wiki
Source0:        http://files.ettus.com/binaries/uhd_stable/latest_release/uhd-%{version}.tar.gz

BuildRequires:  cmake
BuildRequires:  boost-devel
BuildRequires:  pkgconfig(libusb-1.0)
BuildRequires:  pkgconfig(orc-0.4)
BuildRequires:  python-cheetah
BuildRequires:  python-docutils
BuildRequires:  python-mako
BuildRequires:  doxygen
BuildRequires:  pkgconfig

%description
The UHD is the universal hardware driver for Ettus Research products.
The goal of the UHD is to provide a host driver and API for current and
future Ettus Research products. It can be used standalone without GNU Radio.

%prep
%setup -q -n %{uname}_%{version}_release

%build
%cmake

%make_build

%install
%make_install -C build

# Allow access only to users in usrp group
mkdir -p %{buildroot}%{_udevrulesdir}
mv %{buildroot}%{_libdir}/uhd/utils/uhd-usrp.rules %{buildroot}%{_udevrulesdir}/10-usrp-uhd.rules
sed -i 's/MODE:="0666"/MODE:="0660"/' %{buildroot}%{_udevrulesdir}/10-usrp-uhd.rules

# Remove binaries for tests, examples
rm -rf %{buildroot}%{_libdir}/uhd/{tests,examples}

# Move the utils stuff to libexec dir
mkdir -p %{buildroot}%{_libexecdir}/uhd
mv %{buildroot}%{_libdir}/uhd/utils %{buildroot}%{_libexecdir}/uhd/utils
mv %{buildroot}%{_datadir}/uhd/rfnoc %{buildroot}%{_libexecdir}/uhd/

# Package base docs to base package
mkdir _tmpdoc
mv %{buildroot}%{_docdir}/%{name}/{LICENSE,README.md} _tmpdoc

%package -n %{libname}
Summary:        Library files for %{uname}
Group:          Communications/Radio
Requires:       %{name} = %{version}-%{release}
Conflicts:      %{name} < 3.10.1.1

%description -n %{libname}
Library files for the Universal Hardware Driver (UHD).

%package -n %{devname}
Summary:        Development files for UHD
Group:          Communications/Radio
Requires:       %{libname} = %{version}-%{release}
Provides:       %{name}-devel = %{version}-%{release}
Conflicts:      %{name}-devel < 3.10.1.1
Obsoletes:      %{name}-devel < 3.10.1.1

%description -n %{devname}
Development files for the Universal Hardware Driver (UHD).

%package doc
Summary:        Documentation files for UHD
Group:          Communications/Radio
BuildArch:      noarch

%description doc
Documentation for the Universal Hardware Driver (UHD).

%pre -n uhd
getent group usrp >/dev/null || groupadd -r usrp

%files
%doc _tmpdoc/*
%{_bindir}/octoclock_firmware_burner
%{_bindir}/uhd_find_devices
%{_bindir}/uhd_usrp_probe
%{_bindir}/uhd_cal_rx_iq_balance
%{_bindir}/uhd_cal_tx_dc_offset
%{_bindir}/uhd_cal_tx_iq_balance
%{_bindir}/uhd_image_loader
%{_bindir}/uhd_images_downloader
%{_bindir}/uhd_config_info
%{_bindir}/usrp2_card_burner
%{_bindir}/usrp_x3xx_fpga_burner
%{_bindir}/usrp_n2xx_simple_net_burner
%{_udevrulesdir}/10-usrp-uhd.rules
%{_libexecdir}/uhd

%files -n %{libname}
%{_libdir}/lib%{name}.so.%{major}{,.*}

%files -n %{devname}
%{_includedir}/*
%{_libdir}/lib%{name}.so
%{_libdir}/pkgconfig/*.pc
%{_libdir}/cmake/uhd/*.cmake

%files doc
%doc %{_docdir}/%{name}/*
%{_mandir}/man1/*


%changelog
* Wed Feb 15 2017 barjac <barjac> 3.10.1.1-1.mga6
+ Revision: 1086302
- new version 3.10.1.1
- moved lib into separate package using %%mklibname
- changed to handle upstream file structure changes
- fixed upstream tarball and directory naming
- sorted conflicts/obsoletes for moved/renamed packages

* Tue Sep 06 2016 barjac <barjac> 3.9.5-1.mga6
+ Revision: 1050270
- new version 3.9.5
- spec tidy

* Tue May 10 2016 barjac <barjac> 3.9.4-1.mga6
+ Revision: 1011827
- new version 3.9.4

* Thu Mar 24 2016 barjac <barjac> 3.9.3-1.mga6
+ Revision: 994694
- new version 3.9.3

* Thu Dec 31 2015 barjac <barjac> 3.9.2-1.mga6
+ Revision: 917030
- new version 3.9.2

* Thu Dec 24 2015 barjac <barjac> 3.9.1-2.mga6
+ Revision: 914236
- rebuild for boost-1.60.0

* Thu Dec 10 2015 barjac <barjac> 3.9.1-1.mga6
+ Revision: 909266
- new version 3.9.1
- fix %%files
- clean spec

* Thu Sep 24 2015 barjac <barjac> 3.8.5-3.mga6
+ Revision: 883361
- rebuild for boost-1.59

* Mon Aug 24 2015 barjac <barjac> 3.8.5-2.mga6
+ Revision: 868934
- rebuild for boost-1.58

* Wed Aug 12 2015 fwang <fwang> 3.8.5-1.mga6
+ Revision: 863478
- update file list
- 3.8.5

  + daviddavid <daviddavid>
    - rebuild for new boost-1.58.0

* Wed Oct 15 2014 umeabot <umeabot> 3.7.2-3.mga5
+ Revision: 747090
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 3.7.2-2.mga5
+ Revision: 690028
- Mageia 5 Mass Rebuild

* Tue Sep 02 2014 barjac <barjac> 3.7.2-1.mga5
+ Revision: 671062
- new version 3.7.2

* Mon Jun 09 2014 barjac <barjac> 3.7.1-1.mga5
+ Revision: 634933
- new version 3.7.1
- fix files list

* Mon Feb 10 2014 barjac <barjac> 3.6.2-1.mga5
+ Revision: 588137
- new version 3.6.2
- changed vcs repo url
- fix broken path since 3.6.0
- fix file list

* Sat Oct 19 2013 umeabot <umeabot> 3.5.3-3.mga5
+ Revision: 529658
- Mageia 4 Mass Rebuild

* Thu Jul 11 2013 fwang <fwang> 3.5.3-2.mga4
+ Revision: 452819
- rebuild for new boost

* Fri May 31 2013 barjac <barjac> 3.5.3-1.mga4
+ Revision: 433512
- new version 3.5.3

* Wed Apr 10 2013 barjac <barjac> 3.5.1-2.mga3
+ Revision: 409431
- rebuild for boost-1.53

* Fri Feb 01 2013 barjac <barjac> 3.5.1-1.mga3
+ Revision: 393856
- new version 3.5.1

* Mon Jan 14 2013 fwang <fwang> 3.5.0-2.mga3
+ Revision: 385731
- update udev rules dir

  + umeabot <umeabot>
    - Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Mon Jan 07 2013 barjac <barjac> 3.5.0-1.mga3
+ Revision: 341382
- new version 3.5.0

* Thu Dec 20 2012 fwang <fwang> 3.4.3-3.mga3
+ Revision: 333112
- rebuild for new boost

* Fri Sep 28 2012 barjac <barjac> 3.4.3-2.mga3
+ Revision: 299080
- Changed group to new policy

* Sat Sep 22 2012 barjac <barjac> 3.4.3-1.mga3
+ Revision: 296773
- New version 3.4.3

* Tue Jul 31 2012 fwang <fwang> 3.4.2-2.mga3
+ Revision: 276501
- rebuild for new boost

* Sat Jun 09 2012 barjac <barjac> 3.4.2-1.mga3
+ Revision: 258969
- New version 3.4.2
- changed BR libusb1.0-devel
- Minor edit to make-tarball script

* Wed May 30 2012 fwang <fwang> 3.4.1-2.mga3
+ Revision: 249873
- disable check
- drop unused command
- rebuild for new boost

* Sat Apr 21 2012 barjac <barjac> 3.4.1-1.mga2
+ Revision: 232342
- new version

* Sat Mar 03 2012 barjac <barjac> 3.3.2-1.mga2
+ Revision: 217237
- new version 3.3.2
- added make-tarball script for simpler updates

* Sat Jan 14 2012 barjac <barjac> 3.3.1-1.mga2
+ Revision: 196168
- Corrected Group in sub packages
- Cleaned
- Added BR orc
- Removed %%post, %%postun ldconfig
- Changed Group tag
- imported package uhd

